@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 
-from os import mkdir
 from os.path import exists
+from os import mkdir, system
 
 from linux_profile.base.storage import Storage
 from linux_profile.utils.file import get_system, get_distro
-from linux_profile.settings import FILE, FOLDER
+from linux_profile.settings import file_location, folder_location
 
 
 class BaseConfig():
@@ -15,8 +15,8 @@ class BaseConfig():
             module: str = None,
             tag: str = None,
             item: str = None,
-            _file: dict = FILE,
-            _folder: dict = FOLDER,
+            _file: dict = file_location,
+            _folder: dict = folder_location,
             **kwargs):
         """
         Structure that defines the main variables.
@@ -32,6 +32,7 @@ class BaseConfig():
                 setattr(self, arg, kwargs.get(arg))
 
         self.set_folder()
+        self.set_file()
 
         self.class_profile = Storage(database=self.file.get('profile'))
         self.class_config = Storage(database=self.file.get('config'))
@@ -56,7 +57,16 @@ class BaseConfig():
         """
         for folder in self.folder:
             if not exists(self.folder.get(folder)):
-                mkdir(self.folder.get(folder))
+                system(f"sudo mkdir {self.folder.get(folder)}")
+
+    def set_file(self) -> None:
+        """
+        Setup File
+
+        Checks and creates files.
+        """
+        if not exists(self.file.get('bash_aliases')):
+            system(f"touch {self.file.get('bash_aliases')}")
 
     def add_config(self):
         """
