@@ -1,20 +1,26 @@
+#!/usr/bin/env python3
+
 import argparse
 
 from linux_profile.base.command import BaseCommand, Command
-from linux_profile.commands.init import Init
+
+from linux_profile.commands.config import Config
 from linux_profile.commands.add import Add
 from linux_profile.commands.install import Install
 from linux_profile.commands.uninstall import Uninstall
 from linux_profile.commands.list import List
 
 
-class CommandInit(Command):
+class CommandConfig(Command):
 
     def execute(self):
         """Start
         """
-        Init(module=self.module)
-        
+        Config(
+            module=self.module,
+            **self.arguments.__dict__
+        )
+
 
 class CommandAdd(Command):
 
@@ -64,7 +70,7 @@ def main():
     parser = argparse.ArgumentParser(description='Linux profile management tool')
     command = BaseCommand(parser)
 
-    command.cmd_init.set_defaults(exec=CommandInit)
+    command.cmd_config.set_defaults(exec=CommandConfig)
     command.cmd_add.set_defaults(exec=CommandAdd)
     command.cmd_install.set_defaults(exec=CommandInstall)
     command.cmd_uninstall.set_defaults(exec=CommandUninstall)
